@@ -102,7 +102,7 @@ sunone_util_mangle_uid (ECalComponent *comp)
 	e_cal_component_get_recurid (comp, &rid);	
 	if (!rid.datetime.value)
 		return;
-	tstr = icaltime_as_ical_string (*rid.datetime.value);
+	tstr = icaltime_as_ical_string_r (*rid.datetime.value);
 	e_cal_component_get_uid (comp, &uid);
 
 	new_uid = g_strconcat (uid, tstr, NULL);
@@ -127,7 +127,7 @@ sunone_util_unmangle_uid (ECalComponent *comp)
 	e_cal_component_get_uid (comp, &uid);
 	
 	new_uid = g_strdup (uid);
-	rid_string = icaltime_as_ical_string (*rid.datetime.value);
+	rid_string = icaltime_as_ical_string_r (*rid.datetime.value);
 	new_uid[strlen (uid) - strlen (rid_string)] = '\0';	
 	g_free (rid_string);
 	e_cal_component_set_uid (comp, new_uid);
